pub struct NovaRoute {
pub path: &'static str,
pub method: &'static str,
pub handler: fn() -> MethodRouter<()>,
}Expand description
A route contributed via the inventory macro by attribute macros.
Each route is a static descriptor with a path, method and a handler constructor function used at startup to register the route into the application router.
Fields
path: &'static strmethod: &'static strhandler: fn() -> MethodRouter<()>Trait Implementations