pub struct NovaState<S>(pub S);Expand description
Wrapper extractor for application state.
Use this extractor in handlers to obtain a cloned instance of the
application state type previously injected into the Axum router via
axum::Extension(state) (NovaApp injects the state for you).
Example:
ⓘ
async fn handler(state: NovaState<MyState>) -> impl IntoResponse {
let s: MyState = state.0; // cloned state
// ...
}Tuple Fields
0: STrait Implementations
Sourceimpl<S, State> FromRequestParts<State> for NovaState<S>
impl<S, State> FromRequestParts<State> for NovaState<S>
Sourcetype Rejection = NovaStateRejection
type Rejection = NovaStateRejection
If the extractor fails it’ll use this “rejection” type. A rejection is
a kind of error that can be converted into a response.