pub struct NovaStateRejection;Expand description
Error returned when application state is missing from request extensions.
This occurs when the application failed to add Extension<...> for the
configured state type. The rejection implements IntoResponse and will
produce a 500-level response when returned from an extractor.